==> drd-4.0.x-dev.tar.gz: drd/modules/drd_pi/src/DrdPiDomain.php <==
<?php

namespace Drupal\drd_pi;

use Drupal\drd\Entity\Domain;
use Exception;

/**
 * Provides platform based domain.
 */
class DrdPiDomain extends DrdPiEntity {

  /**
   * The domain name.
   *
   * @var string
   */
  protected $domain;

  /**
   * Core to which this domains is attached.
   *
   * @var DrdPiCore
   */
  protected $core;

  /**
   * Set the core and domain name for this entity.
   *
   * @param DrdPiCore $core
   *   Core to which this domain is attached.
   * @param string $domain
   *   The domain name of this entity.
   *
   * @return $this
   */
  public function setDetails(DrdPiCore $core, $domain): self {
    $this->core = $core;
    $this->domain = $domain;
    return $this;
  }

  /**
   * Determine full remote URL by testing https and http protocol.
   *
   * @param bool $secure
   *   Flag to determine which protocol to test.
   *
   * @return bool|string
   *   Returns the full remote URL including scheme with https as the preference
   *   or FALSE if none of the possible URLs responds to a head request.
   */
  private function determineUrl($secure = TRUE) {
    $scheme = $secure ? 'https' : 'http';
    $options = [];
    if (isset($this->header['Authorization'])) {
      $options['headers']['Authorization'] = $this->header['Authorization'];
    }
    $url = $scheme . '://' . $this->domain;
    $success = FALSE;
    try {
      $client = $this->httpClientFactory->fromOptions(['base_uri' => $url]);
      $response = $client->request('head', $url, $options);
      $statusCode = $response->getStatusCode();
      $success = ($statusCode < 300);
    }
    catch (Exception $ex) {
      // Ignore.
    }
    if (!$success) {
      $this->logging->debug('Can not connect to @url', [
        '@url' => $url,
      ]);
      if ($secure) {
        return $this->determineUrl(FALSE);
      }
      return FALSE;
    }
    return $url;
  }

  /**
   * {@inheritdoc}
   */
  public function host(): DrdPiHost {
    return $this->core->host();
  }

  /**
   * {@inheritdoc}
   */
  public function create(): DrdPiEntityInterface {
    $url = $this->determineUrl();
    if ($url === NULL) {
      $this->logging->log('emergency', 'Unable to determine remote URL');
      return $this;
    }

    /* @var \Drupal\drd\Entity\CoreInterface $core */
    $core = $this->core->getDrdEntity();
    $this->entity = Domain::instanceFromUrl($core, $url, [
      'pi_type' => $this->account->getEntityTypeId(),
      'pi_account' => $this->account->id(),
      'pi_id_host' => $this->host()->id(),
      'pi_id_core' => $this->core->id(),
      'pi_id_domain' => $this->id,
    ]);

    /** @var \Drupal\drd\Entity\DomainInterface $domain */
    $domain = $this->getDrdEntity();
    /** @var \Drupal\drd\Entity\CoreInterface $core */
    $core = $this->core->getDrdEntity();

    $domain->initValues('');

    $this->entity->save();

    if ($domain->authorizeBySecret($this->account->getAuthorizationMethod(), $this->account->getAuthorizationSecrets($this))) {
      if (empty($core->getDrupalRoot())) {
        $domain->initCore($core);
      }
      else {
        $domain->remoteInfo();
      }
    }
    else {
      $this->logging->log('warning', 'This DRD instance is not yet authorized remotely.');
    }

    return $this;
  }

}

==> drd-4.1.x-dev.tar.gz: drd/modules/drd_pi/src/DrdPiDomain.php <==
<?php

namespace Drupal\drd_pi;

use Drupal\drd\Entity\Domain;
use GuzzleHttp\Exception\GuzzleException;

/**
 * Provides platform based domain.
 */
class DrdPiDomain extends DrdPiEntity {

  /**
   * The domain name.
   *
   * @var string
   */
  protected string $domain;

  /**
   * Core to which this domains is attached.
   *
   * @var DrdPiCore
   */
  protected DrdPiCore $core;

  /**
   * Set the core and domain name for this entity.
   *
   * @param DrdPiCore $core
   *   Core to which this domain is attached.
   * @param string $domain
   *   The domain name of this entity.
   *
   * @return $this
   */
  public function setDetails(DrdPiCore $core, string $domain): self {
    $this->core = $core;
    $this->domain = $domain;
    return $this;
  }

  /**
   * Determine full remote URL by testing https and http protocol.
   *
   * @param bool $secure
   *   Flag to determine which protocol to test.
   *
   * @return bool|string
   *   Returns the full remote URL including scheme with https as the preference
   *   or FALSE if none of the possible URLs responds to a head request.
   */
  private function determineUrl(bool $secure = TRUE): bool|string {
    $scheme = $secure ? 'https' : 'http';
    $options = [];
    if (isset($this->header['Authorization'])) {
      $options['headers']['Authorization'] = $this->header['Authorization'];
    }
    $url = $scheme . '://' . $this->domain;
    $success = FALSE;
    try {
      $client = $this->httpClientFactory->fromOptions(['base_uri' => $url]);
      $response = $client->request('head', $url, $options);
      $statusCode = $response->getStatusCode();
      $success = ($statusCode < 300);
    }
    catch (\Exception | GuzzleException) {
      // Ignore.
    }
    if (!$success) {
      $this->logging->debug('Can not connect to @url', [
        '@url' => $url,
      ]);
      if ($secure) {
        return $this->determineUrl(FALSE);
      }
      return FALSE;
    }
    return $url;
  }

  /**
   * {@inheritdoc}
   */
  public function host(): DrdPiHost {
    return $this->core->host();
  }

  /**
   * {@inheritdoc}
   */
  public function create(): DrdPiEntityInterface {
    $url = $this->determineUrl();
    if ($url === FALSE) {
      $this->logging->log('emergency', 'Unable to determine remote URL');
      return $this;
    }

    /** @var \Drupal\drd\Entity\CoreInterface $core */
    $core = $this->core->getDrdEntity();
    $this->entity = Domain::instanceFromUrl($core, $url, [
      'pi_type' => $this->account->getEntityTypeId(),
      'pi_account' => $this->account->id(),
      'pi_id_host' => $this->host()->id(),
      'pi_id_core' => $this->core->id(),
      'pi_id_domain' => $this->id,
    ]);

    /** @var \Drupal\drd\Entity\DomainInterface $domain */
    $domain = $this->getDrdEntity();
    /** @var \Drupal\drd\Entity\CoreInterface $core */
    $core = $this->core->getDrdEntity();

    $domain->initValues('');

    $this->entity->save();

    if ($domain->authorizeBySecret($this->account->getAuthorizationMethod(), $this->account->getAuthorizationSecrets($this))) {
      if (empty($core->getDrupalRoot())) {
        $domain->initCore($core);
      }
      else {
        $domain->remoteInfo();
      }
    }
    else {
      $this->logging->log('warning', 'This DRD instance is not yet authorized remotely.');
    }

    return $this;
  }

}
